This function returns a ggplot object with an annotated plot of a generic_spct object.
# S3 method for generic_spct
autoplot(
object,
...,
y.name,
ymin.name = NULL,
ymax.name = NULL,
ylab = ggplot2::waiver(),
w.band = getOption("photobiology.plot.bands", default = list(UVC(), UVB(), UVA(),
PhR())),
range = NULL,
label.qty = "none",
span = NULL,
wls.target = "HM",
annotations = NULL,
time.format = "",
tz = "UTC",
text.size = 2.5,
idfactor = NULL,
facets = FALSE,
ylim = c(NA, NA),
object.label = deparse(substitute(object)),
na.rm = TRUE
)# S3 method for generic_mspct
autoplot(object, ...)
a ggplot object.
A ggplot object.
a cps_spct object.
in the case of collections of spectra, additional arguments passed to the plot methods for individual spectra, otherwise currently ignored.
character Names of the columns to be mapped to the y aesthetic.
character or expression The y-axis label.
a single waveband object or a list of waveband objects.
an R object on which range() returns a vector of length 2, with min annd max wavelengths (nm).
character string giving the type of summary quantity to use for labels, one of "mean", "total", "contribution", and "relative".
a peak is defined as an element in a sequence which is greater than all other elements within a window of width span centered at that element.
numeric vector indicating the spectral quantity values for
which wavelengths are to be searched and interpolated if need. The
character strings "half.maximum" and "half.range" are also accepted
as arguments. A list with numeric and/or character values is
also accepted.
a character vector ("summaries" is ignored). For details please see sections Plot Annotations and Title Annotations.
character Format as accepted by strptime.
character Time zone to use for title and/or subtitle.
numeric size of text in the plot decorations.
character Name of an index column in data holding a
factor with each spectrum in a long-form multispectrum object
corresponding to a distinct spectrum. If idfactor=NULL the name of
the factor is retrieved from metadata or if no metadata found, the
default "spct.idx" is tried.
logical or integer Indicating if facets are to be created for
the levels of idfactor when spct contain multiple spectra in
long form.
numeric y axis limits (expansion only!).
character The name of the object being plotted.
logical.
The recognized annotation names are: "summaries", "peaks",
"peak.labels", "valleys", "valley.labels",
"wls", "wls.labels", "colour.guide",
"color.guide", "boxes", "segments", "labels".
In addition, "+" is interpreted as a request to add to the already
present default annotations, "-" as request to remove annotations
and "=" or missing"+" and "-" as a request to reset
annotations to those requested. If used, "+", "-" or
"=" must be the first member of a character vector, and followed by
one or more of the names given above. To simultaneously add and remove
annotations one can pass a list containing character vectors
each assembled as described. The vectors are applied in the order they
appear in the list. To disable all annotations pass "" or
c("=", "") as argument. Adding a variation of an annotation already
present, replaces the existing one automatically: e.g., adding
"peak.labels" replaces"peaks" if present.
metadata retrieved from object object is
paased to ggplot2::ggtitle() as arguments for title,
subtitle and caption. The specification for the title is
passed as argument to annotations, and consists in the keyword
title with optional modifiers selecting the kind of metatdata to
use, separated by colons. Up to three keywords separated by colons are
accepted, and correspond to title, subtitle and caption. The recognized
keywords are: "objt", "class", "what", "when",
"where", "how", "inst.name", "inst.sn",
"comment" and "none" are recognized as modifiers to
"title"; "none" is a placeholder. Default is
"title:objt" or no title depending on the context.
No automatic plot method is possible for objects of class generic_spct
as this class is meant to be mainly used only as a pure base class for
derivation. A method is provided for generic_spct but not for
generic_mspct as generic_mspct objects can contain an
assortment of objects including generic_spct and classes derived from
generic_spct making the spectra are unlikely be suitable for plotting
in the same ggplot.
Contrary to other autoplot methods, the method for generic_spct does
not supply defaults to several of its parameters and cannot be used simply by
calling it with the spectrum as argument. There are also limitations on which
annotations are accepted. On-the-fly normalization is not supported.
normalize,
generic_spct,
waveband,
photobiologyWavebands-package,
scale_continuous and
autoplot
sun.generic_spct <- as.generic_spct(sun.spct)
autoplot(sun.generic_spct, y.name = "s.q.irrad")
autoplot(sun.generic_spct, y.name = "s.q.irrad",
annotations = "")
autoplot(sun.generic_spct, y.name = "s.q.irrad",
annotations = "title:objt:when",
ylab = s.q.irrad_label(unit.exponent = 0))
autoplot(sun.generic_spct, y.name = "s.e.irrad",
annotations = "colour.guide")
autoplot(sun.generic_spct, y.name = "s.q.irrad",
ylim = c(-1e-6, 4e-6))
Run the code above in your browser using DataLab