autotitle() retrieves from object object metadata and
passes it to ggplot2::ggtitle() as arguments for title,
subtitle and caption. The specification for the tittle is
passed as argument to annotations, and consists in the keyword
title with optional modifiers selecting the kind of metatdata to
use, separated by colons. Up to three keywords separated by colons are
accepted, and correspond to title, subtitle and caption. The recognized
keywords are: "objt", "class", "what", "when", "where", "how", "inst.name",
"inst.sn", "comment" and "none" are recognized as modifiers to "title";
"none" is a placeholder.