Scale y continuous with defaults suitable for raw the calibration multipliers used to convert pixel response rate (counts per second) into energy irradiance units.
scale_y_multipliers_continuous(
unit.exponent = 0,
name = multipliers_label(unit.exponent = unit.exponent, format = format, label.text =
label.text, scaled = scaled, normalized = round(normalized, 1)),
labels = SI_pl_format(exponent = unit.exponent),
format = getOption("photobiology.math", default = "R.expression"),
label.text = axis_labels()[["e.mult"]],
scaled = FALSE,
normalized = FALSE,
...
)integer
The name of the scale, used for the axis-label.
The tick labels or a function to generate them.
character string, "R", "R.expression", "R.character", or "LaTeX".
character Textual portion of the labels.
logical If TRUE relative units are assumed.
logical (FALSE) or numeric Normalization wavelength
in manometers (nm).
other named arguments passed to scale_y_continuous