| stat_color | R Documentation |
stat_color computes colour definitions according to human vision.
stat_color(
mapping = NULL,
data = NULL,
geom = "point",
position = "identity",
...,
chroma.type = "CMF",
x.colour.transform = function(x) {
x
},
na.rm = FALSE,
show.legend = FALSE,
inherit.aes = TRUE
)
mapping |
The aesthetic mapping, usually constructed with
|
data |
A layer specific dataset - only needed if you want to override the plot defaults. |
geom |
The geometric object to use display the data |
position |
The position adjustment to use for overlapping points on this layer |
... |
other arguments passed on to |
chroma.type |
character one of "CMF" (color matching function) or "CC"
(color coordinates) or a |
x.colour.transform |
function Applied to |
na.rm |
a logical value indicating whether NA values should be stripped before the computation proceeds. |
show.legend |
logical. Should this layer be included in the legends?
|
inherit.aes |
If |
For each row in data a colour definition is computed assuming
that after transformation with x.colour.transform() the values in
x are wavelengths expressed in nanometres.
The original data frame with variable wl.color containing
colour definitions added.
color corresponding to x-value giving wavelength in nanometres.
Set by the statistic and available to geoms.
after_stat(wl.color)
after_stat(wl.color)
Required by the statistic and need to be set with aes().
numeric, wavelength in nanometres
numeric, a spectral quantity
color_of, which is used internally.
Other stats functions:
stat_find_qtys(),
stat_find_wls(),
stat_label_peaks(),
stat_peaks(),
stat_spikes(),
stat_wb_box(),
stat_wb_column(),
stat_wb_contribution(),
stat_wb_hbar(),
stat_wb_irrad(),
stat_wb_label(),
stat_wb_mean(),
stat_wb_relative(),
stat_wb_sirrad(),
stat_wb_total(),
stat_wl_strip(),
stat_wl_summary()
ggplot(sun.spct) +
geom_line() +
stat_color() +
scale_color_identity()
ggplot(sun.spct) +
geom_line() +
stat_color(x.colour.transform = function(x) {-x}) +
scale_color_identity() +
scale_x_reverse()
ggplot(sun.spct) +
geom_line() +
stat_color(x.colour.transform = function(x) {10^x}) +
scale_color_identity() +
scale_x_log10()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.