View source: R/autoplot-utils.R
| validate_geom_arg | R Documentation |
autoplot() methods have a geom parameter that supports a subset of
existing geoms. This function factors this check out of the methods' code.
validate_geom_arg(
geoms = character(),
supported.geoms = c("area", "line", "spct", "col", "point"),
default.geoms = "line"
)
geoms, supported.geoms, default.geoms |
character A vector of geom names. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.