validate_geom_arg: Validate argument passed to geom
Description
autoplot() methods have a geom parameter that supports a subset of
existing geoms. This function factors this check out of the methods' code.
Usage
validate_geom_arg(
geoms = character(),
supported.geoms = c("area", "line", "spct", "col", "point"),
default.geoms = "line"
)Arguments
- geoms, supported.geoms, default.geoms
character A vector of geom names.